<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="57"/>
        <location filename="../mainwindow.cpp" line="125"/>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>MX Snapshot</source>
        <translation>MX 快照</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>快照存放位置：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;快照工具是為電腦正在運作的系統製作一份可開機映像檔（ISO），此檔案可以用來備份或流通。當它在執行的時候，你仍然可以繼續使用不太消耗資源的程式。&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>/（根目錄）和 /home 磁碟區已使用的空間：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="851"/>
        <source>Snapshot name:</source>
        <translation>快照檔名：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>將快照存放在別的目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="215"/>
        <source>lz4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>lzo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="225"/>
        <source>gzip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>xz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation>此外，你還可以排除某些目錄，使其不納入快照中。方法是勾選這些常見的目錄，或是按下面的按鈕，直接編輯 /etc/mx-snapshot-exclude.list 檔案。</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="345"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>All of the above</source>
        <translation>以上全選</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="352"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="373"/>
        <source>Videos</source>
        <translation>影片</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;選擇此項，則會回復 MX Linux 預設的 demo 和 root 帳密，而不複製任何自訂的個人帳號資料。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>重新設定帳密（公開流通用）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Type of snapshot:</source>
        <translation>快照類型：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="445"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>保留帳密（個人備份用）</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>ISO compression scheme:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <source>Edit Exclusion File</source>
        <translation>編輯排除檔</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>Display help </source>
        <translation>顯示說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Help</source>
        <translation>說明</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <source>About this application</source>
        <translation>關於本程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>About...</source>
        <translation>關於……</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="652"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Quit application</source>
        <translation>退出程式</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="678"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="694"/>
        <source>Next</source>
        <translation>下一個</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="736"/>
        <source>Back</source>
        <translation>後退</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>Used space on / (root): </source>
        <translation>/（根目錄）使用的空間：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Used space on /home: </source>
        <translation>/home 使用的空間：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>快照目錄所在的 %1 尚可利用的空間：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>所餘空間當足以存放 / 和 /home 的壓縮資料

      若有必要，可以移除早先的快照，以換取更多空間：
      目前有 %1 組快照，使用了 %2 磁碟空間。
</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>Installing </source>
        <translation>正在安裝……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="647"/>
        <location filename="../mainwindow.cpp" line="663"/>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Could not install </source>
        <translation>無法安裝</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>Building new initrd...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="348"/>
        <source>Copying the new-iso filesystem...</source>
        <translation>正在複製 new-iso 檔案系統……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>Squashing filesystem...</source>
        <translation>正在壓縮檔案系統……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="647"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation>無法製作 linuxfs 檔，請檢查目的地磁碟區是否還有足夠的空間。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>Creating CD/DVD image file...</source>
        <translation>正在創造 CD/DVD 映像檔……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation>無法製作 ISO 檔，請檢查目的地磁碟區是否還有足夠的空間。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Making hybrid iso</source>
        <translation>正在作混合式 iso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="685"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="686"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="699"/>
        <source>Making md5sum</source>
        <translation>正在作 md5sum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="723"/>
        <source>Cleaning...</source>
        <translation>清理打掃……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="737"/>
        <location filename="../mainwindow.cpp" line="1053"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Please wait.</source>
        <translation>請稍待。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="827"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>請稍待。正在計算佔用多少磁碟空間……</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="842"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="848"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>快照所採取的設定*：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="850"/>
        <source>- Snapshot directory:</source>
        <translation>- 快照存放目錄：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="852"/>
        <source>- Kernel to be used:</source>
        <translation>- 使用核心：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="862"/>
        <source>Final chance</source>
        <translation>最後確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="863"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>快照工具已經掌握了所有相關資料，可以從現在運行的系統中創造出 ISO 檔。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="864"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>要花上一些時間才能完成，實際狀況取決於現行系統大小以及電腦性能。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="865"/>
        <source>OK to start?</source>
        <translation>可以開始嗎？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="874"/>
        <source>Output</source>
        <translation>輸出</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="881"/>
        <source>Edit Boot Menu</source>
        <translation>編輯開機選單</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="882"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>本程式即將暫停，讓你有機會編修工作目錄之中的每個檔案。選擇「是」便可編輯開機選單，選擇「否」 則會省略此一步驟，直接製作快照。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="895"/>
        <source>Success</source>
        <translation>成功</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="895"/>
        <source>All finished!</source>
        <translation>全部完畢！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1007"/>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1012"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1027"/>
        <source>%1 Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MX Snapshot</source>
        <translation type="vanished">關於 MX 快照</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1008"/>
        <source>Version: </source>
        <translation>版本：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1009"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>本程式可將正在運作的 MX Linux 系統做成現場版 CD</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1011"/>
        <source>Copyright (c) MX Linux</source>
        <translation>版權所有 (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">授權條款</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">關閉（&amp;C）</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <source>Select Snapshot Directory</source>
        <translation>選擇快照目錄</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>真的要退出此程式嗎？</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="75"/>
        <location filename="../main.cpp" line="86"/>
        <source>Error</source>
        <translation>錯誤</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>You must run this program as root.</source>
        <translation>本程式必須以 root 身份來執行。</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation type="unfinished">授權條款</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation type="unfinished">取消</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation type="unfinished">關閉（&amp;C）</translation>
    </message>
</context>
</TS>
